<h1 align="center">kilroy-face-debug</h1>

<div align="center">

kilroy face for debugging 🧪

[![Lint](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/lint.yaml/badge.svg)](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/lint.yaml)
[![Multiplatform tests](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/test-multiplatform.yaml/badge.svg)](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/test-multiplatform.yaml)
[![Docker tests](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/test-docker.yaml/badge.svg)](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/test-docker.yaml)
[![Docs](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/docs.yaml/badge.svg)](https://github.com/kilroybot/kilroy-face-debug/actions/workflows/docs.yaml)

</div>

---

## Installing

Using `pip`:

```sh
pip install kilroy-face-debug
```

## Usage

To run the face server, install the package and run the following command:

```sh
kilroy-face-debug
```

This will start the face server on port 9999 by default.
Then you can communicate with the server, for example by using
[this package](https://github.com/kilroybot/kilroy-face-client-py-sdk).
